@@ -45,6 +45,10 @@ setMethodS3("findUnitNamesFile", "AromaPlatform", abstract=TRUE);
 
 setMethodS3("getUnitNamesFile", "AromaPlatform", abstract=TRUE);
 
+setMethodS3("findUnitTypesFile", "AromaPlatform", abstract=TRUE);
+
+setMethodS3("getUnitTypesFile", "AromaPlatform", abstract=TRUE);
+
 
 setMethodS3("getAromaUgpFile", "AromaPlatform", function(static, ...) {
   AromaUgpFile$byName(...);
@@ -55,6 +59,8 @@ setMethodS3("getAromaUgpFile", "AromaPlatform", function(static, ...) {
 
 ############################################################################
 # HISTORY:
+# 2009-07-08
+# o Added getUnitTypesFile() for AromaPlatform.
 # 2008-05-18
 # o Created.
 ############################################################################
